﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Infragistics.Controls.Schedules;

namespace ScheduleResourceToolTip
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            Loaded += MainWindow_Loaded;
        }

        void MainWindow_Loaded(object sender, RoutedEventArgs e)
        {
            ObservableCollection<Resource> resources = new ObservableCollection<Resource>();
            Resource resAmanda = new Resource() { Id = "amanda", Name = "Amanda", EmailAddress = "amanda@email.com" };
            resources.Add(resAmanda);
            Resource resSteve = new Resource() { Id = "steve", Name = "Steve", EmailAddress = "steve@email.com"  };
            resources.Add(resSteve);

            ObservableCollection<ResourceCalendar> calendars = new ObservableCollection<ResourceCalendar>();
            ResourceCalendar calAmanda = new ResourceCalendar() { Id = "amandaCal", OwningResourceId = "amanda"  };
            calendars.Add(calAmanda);

            ResourceCalendar calSteve = new ResourceCalendar() { Id = "steveCal", OwningResourceId = "steve" };
            calendars.Add(calSteve);

            ObservableCollection<Appointment> appointments = new ObservableCollection<Appointment>();
            Appointment app1 = new Appointment()
            {
                Id = "t1",
                OwningResourceId = "amanda",
                OwningCalendarId = "amandaCal",
                Subject = "Appointment 1",
                Description = "My first appointment",
                // Convert the date to universal time, because a time zone is not set
                // in this snippet    
                Start = DateTime.Today.AddHours(9).AddMinutes(12).ToUniversalTime(),
                End = DateTime.Today.AddHours(11).AddMinutes(42).ToUniversalTime()
            };
            appointments.Add(app1);
            Appointment app2 = new Appointment()
            {
                Id = "t2",
                OwningResourceId = "amanda",
                OwningCalendarId = "amandaCal",
                Subject = "Appointment 2",
                Description = "My second appointment",
                // Convert the date to universal time, because a time zone is not set
                // in this snippet    
                Start = DateTime.Today.AddHours(10).AddMinutes(12).ToUniversalTime(),
                End = DateTime.Today.AddHours(11).AddMinutes(42).ToUniversalTime()
            };
            appointments.Add(app2);

            ListScheduleDataConnector dataConnector = new ListScheduleDataConnector();
            dataConnector.ResourceItemsSource = resources;
            dataConnector.ResourceCalendarItemsSource = calendars;
            dataConnector.AppointmentItemsSource = appointments;

            XamScheduleDataManager dataManager = new XamScheduleDataManager();
            dataManager.DataConnector = dataConnector;
            CalendarGroupCollection calGroups = dataManager.CalendarGroups;
            CalendarGroup calGroup = new CalendarGroup();
            calGroup.InitialCalendarIds = "amanda[amandaCal],steve[steveCal]";
            calGroups.Add(calGroup);

            XamScheduleView dayView = new XamScheduleView();
            dayView.DataManager = dataManager;
            this.LayoutRoot.Children.Add(dayView);
        }
    }
}
